OrderableDBInstanceOption class

The options that are available for an instance.

Constructors

OrderableDBInstanceOption({List<AvailabilityZone>? availabilityZones, String? dBInstanceClass, String? engine, String? engineVersion, String? licenseModel, bool? vpc})
OrderableDBInstanceOption.fromXml(XmlElement elem)
factory

Properties

availabilityZones → List<AvailabilityZone>?
A list of Availability Zones for an instance.
final
dBInstanceClass → String?
The instance class for an instance.
final
engine → String?
The engine type of an instance.
final
engineVersion → String?
The engine version of an instance.
final
hashCode → int
The hash code for this object.
no setterinherited
licenseModel → String?
The license model for an instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpc → bool?
Indicates whether an instance is in a virtual private cloud (VPC).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited